#  WSeg

A Python library to perform word segmentation in various fields

## Functions

1. Dictionary-based word segmentation methods (BMM, FMM, and BIMM)
2. Hidden Markov Model (HMM)-based word segmentation method

## License
The `wseg` project is provided by [Donghua Chen](https://github.com/dhchenx/umls-graph). 
